@@ -2,7 +2,7 @@ from .requestManager.requestManager import requestManager
 from .urlManager.urlManager import urlManager
 from .soupManager.soupManager import soupManager
 from .linkManager.linkManager import linkManager
-import threading,os,re,yt_dlp,urllib.request,m3u8_To_MP4,subprocess,requests,,tempfile
+import threading,os,re,yt_dlp,urllib.request,m3u8_To_MP4,subprocess,requests,ffmpeg,tempfile
 from abstract_utilities import get_logFile,safe_dump_to_file,get_time_stamp
 from m3u8 import M3U8  # Install: pip install m3u8
 from urllib.parse import urljoin
